@@ -60,30 +60,33 @@ def calc_fixbond_structures(value_date: str, bond_info: FixedRateBond, setting:
                             ql_business_day[setting.terminate_business_day],
                             ql_date_generation[setting.date_gen],
                             setting.is_eom)
-
+    
     # a sequence of QuantLib.QuantLib.SimpleCashFlow
     interests = ql.FixedRateLeg(schedule, 
                             ql_day_count[setting.day_count],
                             [bond_info.face_value], 
-                            [bond_info.coupon/100])
+                            [bond_info.coupon/100],
+                            ql_business_day[setting.business_day])
     no_of_interests = len(interests)
+    schedule = list(schedule)
+    no_of_dates = len(schedule)
+    startdates = schedule[:no_of_dates - 1]
+    enddates = schedule[1: no_of_dates]
     structures = []
     for i in range(no_of_interests):
         if i == no_of_interests - 1:
-            thestructure = {"start_date": schedule[i].ISO(),
-                            "end_date": interests[i].date().ISO(),
-                            "face_value": bond_info.face_value,
-                            "coupon": bond_info.coupon,
-                            "face_value_flow": bond_info.face_value,
-                            "interest": interests[i].amount(),
-                            "cashflow": bond_info.face_value + interests[i].amount()} 
-        else:
-            thestructure = {"start_date": schedule[i].ISO(),
-                            "end_date": interests[i].date().ISO(),
-                            "face_value": bond_info.face_value,
-                            "coupon": bond_info.coupon,
-                            "interest": interests[i].amount(),
-                            "cashflow": interests[i].amount()}
+            cashflow = bond_info.face_value + interests[i].amount()
+        else :
+            cashflow = interests[i].amount()
+        thestructure = {"start_date": startdates[i].ISO(),
+                        "end_date": enddates[i].ISO(),
+                        "payment_date": interests[i].date().ISO(),
+                        "face_value": bond_info.face_value,
+                        "coupon": bond_info.coupon,
+                        "face_value_flow": bond_info.face_value,
+                        "interest": interests[i].amount(),
+                        "cashflow": cashflow} 
+        
         structure = Structure(**thestructure)  
         structures.append(structure)  
     
